@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -421,7 +421,7 @@ g_mime_signer_new (void)
 {
 	GMimeSigner *signer;
 	
-	signer = g_slice_new (GMimeSigner);
+	signer = g_new (GMimeSigner, 1);
 	signer->status = GMIME_SIGNER_STATUS_NONE;
 	signer->errors = GMIME_SIGNER_ERROR_NONE;
 	signer->trust = GMIME_SIGNER_TRUST_NONE;
@@ -448,8 +448,7 @@ g_mime_signer_free (GMimeSigner *signer)
 	g_free (signer->fingerprint);
 	g_free (signer->keyid);
 	g_free (signer->name);
-	
-	g_slice_free (GMimeSigner, signer);
+	g_free (signer);
 }
 
 
@@ -658,9 +657,9 @@ g_mime_signer_set_name (GMimeSigner *signer, const char *name)
  * g_mime_signer_get_name:
  * @signer: a #GMimeSigner
  *
- * Get the signer's name.
+ * Get the signer trust.
  *
- * Returns: the signer's name.
+ * Returns: the signer trust.
  **/
 const char *
 g_mime_signer_get_name (GMimeSigner *signer)
@@ -749,7 +748,7 @@ g_mime_signature_validity_new (void)
 {
 	GMimeSignatureValidity *validity;
 	
-	validity = g_slice_new (GMimeSignatureValidity);
+	validity = g_new (GMimeSignatureValidity, 1);
 	validity->status = GMIME_SIGNATURE_STATUS_NONE;
 	validity->signers = NULL;
 	validity->details = NULL;
@@ -775,13 +774,16 @@ g_mime_signature_validity_free (GMimeSignatureValidity *validity)
 	signer = validity->signers;
 	while (signer != NULL) {
 		next = signer->next;
-		g_mime_signer_free (signer);
+		g_free (signer->fingerprint);
+		g_free (signer->keyid);
+		g_free (signer->name);
+		g_free (signer);
 		signer = next;
 	}
 	
 	g_free (validity->details);
 	
-	g_slice_free (GMimeSignatureValidity, validity);
+	g_free (validity);
 }
 
 
