@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -130,9 +130,9 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 	GMimeFilterFrom *from = (GMimeFilterFrom *) filter;
 	struct fromnode *head = NULL, *tail = (struct fromnode *) &head, *node;
 	register char *inptr, *inend;
+	unsigned int left;
 	int fromcount = 0;
 	char *outptr;
-	size_t left;
 	
 	inptr = in;
 	inend = inptr + len;
@@ -146,7 +146,7 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 		}
 		
 		if (c == '\n' || !from->midline) {
-			left = (size_t) (inend - inptr);
+			left = inend - inptr;
 			if (left > 0) {
 				from->midline = TRUE;
 				if (left < 5) {
@@ -202,14 +202,14 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 			node = node->next;
 		}
 		
-		memcpy (outptr, inptr, (size_t) (inend - inptr));
+		memcpy (outptr, inptr, (unsigned) (inend - inptr));
 		outptr += inend - inptr;
 		*out = filter->outbuf;
-		*outlen = (size_t) (outptr - filter->outbuf);
+		*outlen = outptr - filter->outbuf;
 		*outprespace = filter->outbuf - filter->outreal;
 	} else {
 		*out = in;
-		*outlen = (size_t) (inend - in);
+		*outlen = inend - in;
 		*outprespace = prespace;
 	}
 }
@@ -242,8 +242,8 @@ filter_reset (GMimeFilter *filter)
  * will be escaped to ">From ".
  *
  * Note: If you plan on using a from-filter in mode ARMOR, you should
- * remember to also use a #GMimeFilterBasic filter with an encoding of
- * #GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE.
+ * remember to also use a #GMimeFilterBasic filter with mode
+ * #GMIME_FILTER_BASIC_QP_ENC.
  *
  * Returns: a new from filter with mode @mode.
  **/
