@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -157,12 +157,12 @@ filter_reset (GMimeFilter *filter)
  *
  * Creates a new Md5 filter.
  *
- * Returns a new Md5 filter.
+ * Returns: a new Md5 filter.
  **/
 GMimeFilter *
 g_mime_filter_md5_new (void)
 {
-	return (GMimeFilter *) g_object_new (GMIME_TYPE_FILTER_MD5, NULL);
+	return g_object_newv (GMIME_TYPE_FILTER_MD5, 0, NULL);
 }
 
 
