@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -38,11 +38,27 @@ G_BEGIN_DECLS
 typedef struct _GMimeFilter GMimeFilter;
 typedef struct _GMimeFilterClass GMimeFilterClass;
 
+/**
+ * GMimeFilter:
+ * @parent_object: parent #GObject
+ * @priv: private state data
+ * @outreal: real malloc'd buffer
+ * @outbuf: first writable position allowed (outreal + outpre)
+ * @outptr: current writale position
+ * @outsize: current bytes in @outbuf
+ * @outpre: current prespace of @outbuf
+ * @backbuf: backup buffer
+ * @backsize: backup buffer size
+ * @backlen: number of bytes backed-up in @backbuf
+ *
+ * Base class for filters used by #GMimeStreamFilter.
+ **/
 struct _GMimeFilter {
 	GObject parent_object;
 	
 	struct _GMimeFilterPrivate *priv;
 	
+	/* <protected> */
 	char *outreal;		/* real malloc'd buffer */
 	char *outbuf;		/* first 'writable' position allowed (outreal + outpre) */
 	char *outptr;
@@ -60,11 +76,11 @@ struct _GMimeFilterClass {
 	/* virtual functions */
 	GMimeFilter * (* copy) (GMimeFilter *filter);
 	
-	void (* filter)   (GMimeFilter *filter, char *in, size_t len, size_t prespace,
-			   char **out, size_t *outlen, size_t *outprespace);
+	void (* filter)   (GMimeFilter *filter, char *inbuf, size_t inlen, size_t prespace,
+			   char **outbuf, size_t *outlen, size_t *outprespace);
 	
-	void (* complete) (GMimeFilter *filter, char *in, size_t len, size_t prespace,
-			   char **out, size_t *outlen, size_t *outprespace);
+	void (* complete) (GMimeFilter *filter, char *inbuf, size_t inlen, size_t prespace,
+			   char **outbuf, size_t *outlen, size_t *outprespace);
 	
 	void (* reset)    (GMimeFilter *filter);
 };
@@ -76,12 +92,12 @@ GType g_mime_filter_get_type (void);
 GMimeFilter *g_mime_filter_copy (GMimeFilter *filter);
 
 void g_mime_filter_filter (GMimeFilter *filter,
-			   char *in, size_t len, size_t prespace,
-			   char **out, size_t *outlen, size_t *outprespace);
+			   char *inbuf, size_t inlen, size_t prespace,
+			   char **outbuf, size_t *outlen, size_t *outprespace);
 
 void g_mime_filter_complete (GMimeFilter *filter,
-			     char *in, size_t len, size_t prespace,
-			     char **out, size_t *outlen, size_t *outprespace);
+			     char *inbuf, size_t inlen, size_t prespace,
+			     char **outbuf, size_t *outlen, size_t *outprespace);
 
 void g_mime_filter_reset (GMimeFilter *filter);
 
