@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -134,7 +134,7 @@ g_mime_header_iter_new (void)
 {
 	GMimeHeaderIter *iter;
 	
-	iter = g_slice_new (GMimeHeaderIter);
+	iter = g_new (GMimeHeaderIter, 1);
 	iter->hdrlist = NULL;
 	iter->cursor = NULL;
 	iter->version = 0;
@@ -195,7 +195,7 @@ g_mime_header_iter_free (GMimeHeaderIter *iter)
 {
 	g_return_if_fail (iter != NULL);
 	
-	g_slice_free (GMimeHeaderIter, iter);
+	g_free (iter);
 }
 
 
@@ -527,7 +527,7 @@ g_mime_header_list_new (void)
 {
 	GMimeHeaderList *headers;
 	
-	headers = g_slice_new (GMimeHeaderList);
+	headers = g_new (GMimeHeaderList, 1);
 	headers->writers = g_hash_table_new_full (g_mime_strcase_hash,
 						  g_mime_strcase_equal,
 						  g_free, NULL);
@@ -565,8 +565,7 @@ g_mime_header_list_destroy (GMimeHeaderList *headers)
 	g_hash_table_destroy (headers->writers);
 	g_hash_table_destroy (headers->hash);
 	g_free (headers->raw);
-	
-	g_slice_free (GMimeHeaderList, headers);
+	g_free (headers);
 }
 
 
