@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -23,29 +23,16 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
-
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 #include <fcntl.h>
 #include <errno.h>
-#ifdef G_OS_WIN32
-#include <io.h>
-#endif
 
 #include "gmime-stream-fs.h"
 
+
 #ifndef HAVE_FSYNC
-#ifdef G_OS_WIN32
-/* _commit() is the equivalent of fsync() on Windows, but it aborts the
- * program if the fd is a tty, so we'll just no-op for now... */
 static int fsync (int fd) { return 0; }
-#else
-static int fsync (int fd) { return 0; }
-#endif
 #endif
 
 
@@ -151,15 +138,8 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	ssize_t nread;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
+	if (stream->bound_end != -1 && stream->position >= stream->bound_end)
 		return -1;
-	}
-	
-	if (stream->bound_end != -1 && stream->position >= stream->bound_end) {
-		errno = EINVAL;
-		return -1;
-	}
 	
 	if (stream->bound_end != -1)
 		len = MIN (stream->bound_end - stream->position, (gint64) len);
@@ -171,11 +151,10 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 		nread = read (fs->fd, buf, len);
 	} while (nread == -1 && errno == EINTR);
 	
-	if (nread > 0) {
+	if (nread > 0)
 		stream->position += nread;
-	} else if (nread == 0) {
+	else if (nread == 0)
 		fs->eos = TRUE;
-	}
 	
 	return nread;
 }
@@ -187,15 +166,8 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	size_t nwritten = 0;
 	ssize_t n;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
+	if (stream->bound_end != -1 && stream->position >= stream->bound_end)
 		return -1;
-	}
-	
-	if (stream->bound_end != -1 && stream->position >= stream->bound_end) {
-		errno = EINVAL;
-		return -1;
-	}
 	
 	if (stream->bound_end != -1)
 		len = MIN (stream->bound_end - stream->position, (gint64) len);
@@ -215,12 +187,10 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	if (n == -1 && (errno == EFBIG || errno == ENOSPC))
 		fs->eos = TRUE;
 	
-	if (nwritten > 0) {
+	if (nwritten > 0)
 		stream->position += nwritten;
-	} else if (n == -1) {
-		/* error and nothing written */
+	else if (n == -1)
 		return -1;
-	}
 	
 	return nwritten;
 }
@@ -230,10 +200,7 @@ stream_flush (GMimeStream *stream)
 {
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
-		return -1;
-	}
+	g_return_val_if_fail (fs->fd != -1, -1);
 	
 	return fsync (fs->fd);
 }
@@ -260,8 +227,7 @@ stream_eos (GMimeStream *stream)
 {
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	
-	if (fs->fd == -1)
-		return TRUE;
+	g_return_val_if_fail (fs->fd != -1, TRUE);
 	
 	return fs->eos;
 }
@@ -271,10 +237,8 @@ stream_reset (GMimeStream *stream)
 {
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
+	if (fs->fd == -1)
 		return -1;
-	}
 	
 	if (stream->position == stream->bound_start) {
 		fs->eos = FALSE;
@@ -298,10 +262,7 @@ stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	gint64 real;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
-		return -1;
-	}
+	g_return_val_if_fail (fs->fd != -1, -1);
 	
 	switch (whence) {
 	case GMIME_STREAM_SEEK_SET:
@@ -334,19 +295,15 @@ stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 	}
 	
 	/* sanity check the resultant offset */
-	if (real < stream->bound_start) {
-		errno = EINVAL;
+	if (real < stream->bound_start)
 		return -1;
-	}
 	
 	/* short-cut if we are seeking to our current position */
 	if (real == stream->position)
 		return real;
 	
-	if (stream->bound_end != -1 && real > stream->bound_end) {
-		errno = EINVAL;
+	if (stream->bound_end != -1 && real > stream->bound_end)
 		return -1;
-	}
 	
 	if ((real = lseek (fs->fd, (off_t) real, SEEK_SET)) == -1)
 		return -1;
@@ -373,21 +330,14 @@ stream_length (GMimeStream *stream)
 	GMimeStreamFs *fs = (GMimeStreamFs *) stream;
 	gint64 bound_end;
 	
-	if (fs->fd == -1) {
-		errno = EBADF;
-		return -1;
-	}
-	
 	if (stream->bound_end != -1)
 		return stream->bound_end - stream->bound_start;
 	
 	bound_end = lseek (fs->fd, (off_t) 0, SEEK_END);
 	lseek (fs->fd, (off_t) stream->position, SEEK_SET);
 	
-	if (bound_end < stream->bound_start) {
-		errno = EINVAL;
+	if (bound_end < stream->bound_start)
 		return -1;
-	}
 	
 	return bound_end - stream->bound_start;
 }
@@ -421,10 +371,6 @@ g_mime_stream_fs_new (int fd)
 	GMimeStreamFs *fs;
 	gint64 start;
 	
-#ifdef G_OS_WIN32
-	_setmode (fd, O_BINARY);
-#endif
-	
 	if ((start = lseek (fd, (off_t) 0, SEEK_CUR)) == -1)
 		start = 0;
 	
@@ -440,7 +386,7 @@ g_mime_stream_fs_new (int fd)
 
 /**
  * g_mime_stream_fs_new_with_bounds:
- * @fd: a file descriptor
+ * @fd: file descriptor
  * @start: start boundary
  * @end: end boundary
  *
@@ -454,10 +400,6 @@ g_mime_stream_fs_new_with_bounds (int fd, gint64 start, gint64 end)
 {
 	GMimeStreamFs *fs;
 	
-#ifdef G_OS_WIN32
-	_setmode (fd, O_BINARY);
-#endif
-	
 	fs = g_object_newv (GMIME_TYPE_STREAM_FS, 0, NULL);
 	g_mime_stream_construct (GMIME_STREAM (fs), start, end);
 	fs->owner = TRUE;
@@ -470,7 +412,7 @@ g_mime_stream_fs_new_with_bounds (int fd, gint64 start, gint64 end)
 
 /**
  * g_mime_stream_fs_get_owner:
- * @stream: a #GMimeStreamFs
+ * @stream: fs stream
  *
  * Gets whether or not @stream owns the backend file descriptor.
  *
@@ -488,10 +430,10 @@ g_mime_stream_fs_get_owner (GMimeStreamFs *stream)
 
 /**
  * g_mime_stream_fs_set_owner:
- * @stream: a #GMimeStreamFs
- * @owner: %TRUE if this stream should own the file descriptor or %FALSE otherwise
+ * @stream: fs stream
+ * @owner: owner
  *
- * Sets whether or not @stream owns the backend file descriptor.
+ * Sets whether or not @stream owns the backend FS pointer.
  *
  * Note: @owner should be %TRUE if the stream should close() the
  * backend file descriptor when destroyed or %FALSE otherwise.
