@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -108,18 +108,20 @@ test_sign (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphert
 {
 	GError *err = NULL;
 	Exception *ex;
+	int rv;
 	
-	g_mime_cipher_sign (ctx, "no.user@no.domain",
-			    GMIME_CIPHER_HASH_DEFAULT,
-			    cleartext, ciphertext, &err);
+	rv = g_mime_cipher_context_sign (ctx, "no.user@no.domain",
+					 GMIME_CIPHER_HASH_SHA256,
+					 cleartext, ciphertext, &err);
 	
-	if (err != NULL) {
+	if (rv == -1 || err != NULL) {
 		ex = exception_new ("%s", err->message);
 		g_error_free (err);
 		throw (ex);
 	}
 	
-	v(fprintf (stderr, "signature:\n%.*s\n",
+	v(fprintf (stderr, "signature (%s):\n%.*s\n",
+		   g_mime_cipher_context_hash_name (ctx, rv),
 		   GMIME_STREAM_MEM (ciphertext)->buffer->len,
 		   GMIME_STREAM_MEM (ciphertext)->buffer->data));
 }
@@ -131,8 +133,8 @@ test_verify (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphe
 	GError *err = NULL;
 	Exception *ex;
 	
-	validity = g_mime_cipher_verify (ctx, GMIME_CIPHER_HASH_DEFAULT,
-					 cleartext, ciphertext, &err);
+	validity = g_mime_cipher_context_verify (ctx, GMIME_CIPHER_HASH_DEFAULT,
+						 cleartext, ciphertext, &err);
 	
 	if (validity == NULL) {
 		ex = exception_new ("%s", err->message);
@@ -149,18 +151,17 @@ test_verify (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphe
 }
 
 static void
-test_encrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphertext)
+test_encrypt (GMimeCipherContext *ctx, gboolean sign, GMimeStream *cleartext, GMimeStream *ciphertext)
 {
 	GPtrArray *recipients;
-	GByteArray *buffer;
 	GError *err = NULL;
 	Exception *ex;
 	
 	recipients = g_ptr_array_new ();
 	g_ptr_array_add (recipients, "no.user@no.domain");
 	
-	g_mime_cipher_encrypt (ctx, FALSE, "no.user@no.domain", recipients,
-			       cleartext, ciphertext, &err);
+	g_mime_cipher_context_encrypt (ctx, sign, "no.user@no.domain", recipients,
+				       cleartext, ciphertext, &err);
 	
 	g_ptr_array_free (recipients, TRUE);
 	
@@ -176,25 +177,38 @@ test_encrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciph
 }
 
 static void
-test_decrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciphertext)
+test_decrypt (GMimeCipherContext *ctx, gboolean sign, GMimeStream *cleartext, GMimeStream *ciphertext)
 {
+	GMimeSignatureValidity *sv;
 	Exception *ex = NULL;
 	GMimeStream *stream;
-	GByteArray *buffer;
 	GError *err = NULL;
 	GByteArray *buf[2];
 	
 	stream = g_mime_stream_mem_new ();
 	
-	g_mime_cipher_decrypt (ctx, ciphertext, stream, &err);
-	
-	if (err != NULL) {
+	if (!(sv = g_mime_cipher_context_decrypt (ctx, ciphertext, stream, &err))) {
 		g_object_unref (stream);
 		ex = exception_new ("%s", err->message);
 		g_error_free (err);
 		throw (ex);
 	}
 	
+	if (sign) {
+		if (sv->status != GMIME_SIGNATURE_STATUS_GOOD)
+			ex = exception_new ("expected GOOD signature");
+	} else {
+		if (sv->status != GMIME_SIGNATURE_STATUS_NONE)
+			ex = exception_new ("unexpected signature");
+	}
+	
+	g_mime_signature_validity_free (sv);
+	
+	if (ex != NULL) {
+		g_object_unref (stream);
+		throw (ex);
+	}
+	
 	buf[0] = GMIME_STREAM_MEM (cleartext)->buffer;
 	buf[1] = GMIME_STREAM_MEM (stream)->buffer;
 	
@@ -207,24 +221,68 @@ test_decrypt (GMimeCipherContext *ctx, GMimeStream *cleartext, GMimeStream *ciph
 		throw (ex);
 }
 
-static int
-test_export (GMimeCipherContext *ctx, GMimeStream *ostream)
+static void
+test_export (GMimeCipherContext *ctx, const char *path)
 {
-	GPtrArray *keys;
+	GMimeStream *istream, *ostream;
+	register const char *inptr;
+	const char *inbuf, *outbuf;
+	size_t inlen, outlen;
+	Exception *ex = NULL;
 	GError *err = NULL;
+	GPtrArray *keys;
+	int fd;
+	
+	if ((fd = open (path, O_RDONLY)) == -1)
+		throw (exception_new ("open() failed: %s", strerror (errno)));
+	
+	ostream = g_mime_stream_fs_new (fd);
+	istream = g_mime_stream_mem_new ();
+	g_mime_stream_write_to_stream (ostream, istream);
+	g_mime_stream_reset (istream);
+	g_object_unref (ostream);
 	
 	keys = g_ptr_array_new ();
 	g_ptr_array_add (keys, "no.user@no.domain");
 	
-	g_mime_cipher_export_keys (ctx, keys, ostream, &err);
+	ostream = g_mime_stream_mem_new ();
+	
+	g_mime_cipher_context_export_keys (ctx, keys, ostream, &err);
 	g_ptr_array_free (keys, TRUE);
 	if (err != NULL) {
-		fprintf (stderr, "pgp_export failed: %s\n", err->message);
+		ex = exception_new ("%s", err->message);
+		g_object_unref (istream);
+		g_object_unref (ostream);
 		g_error_free (err);
-		return 0;
+		throw (ex);
 	}
 	
-	return 1;
+	inbuf = GMIME_STREAM_MEM (istream)->buffer->data;
+	inlen = GMIME_STREAM_MEM (istream)->buffer->len;
+	if ((inptr = strstr (inbuf, "\n\n"))) {
+		/* skip past the headers which may have different version numbers */
+		inptr += 2;
+		inlen -= (inptr - inbuf);
+		inbuf = inptr;
+	}
+	
+	outbuf = GMIME_STREAM_MEM (ostream)->buffer->data;
+	outlen = GMIME_STREAM_MEM (ostream)->buffer->len;
+	if ((inptr = strstr (outbuf, "\n\n"))) {
+		/* skip past the headers which may have different version numbers */
+		inptr += 2;
+		outlen -= (inptr - outbuf);
+		outbuf = inptr;
+	}
+	
+	if (outlen != inlen || memcmp (outbuf, inbuf, inlen) != 0)
+		ex = exception_new ("exported key does not match original key");
+	
+	g_object_unref (istream);
+	g_object_unref (ostream);
+	
+	if (ex != NULL)
+		throw (ex);
 }
 
 static void
@@ -239,7 +297,7 @@ import_key (GMimeCipherContext *ctx, const char *path)
 		throw (exception_new ("open() failed: %s", strerror (errno)));
 	
 	stream = g_mime_stream_fs_new (fd);
-	g_mime_cipher_import_keys (ctx, stream, &err);
+	g_mime_cipher_context_import_keys (ctx, stream, &err);
 	g_object_unref (stream);
 	
 	if (err != NULL) {
@@ -269,6 +327,7 @@ int main (int argc, char **argv)
 	system ("/bin/rm -rf ./tmp");
 	system ("/bin/mkdir ./tmp");
 	setenv ("GNUPGHOME", "./tmp/.gnupg", 1);
+	system ("/usr/bin/gpg --list-keys > /dev/null 2>&1");
 	
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] != '-') {
@@ -303,6 +362,17 @@ int main (int argc, char **argv)
 		return EXIT_FAILURE;
 	} finally;
 	
+	key = g_build_filename (datadir, "gmime.gpg.pub", NULL);
+	testsuite_check ("GMimeGpgContext::export");
+	try {
+		test_export (ctx, key);
+		testsuite_check_passed ();
+	} catch (ex) {
+		testsuite_check_failed ("GMimeGpgContext::export failed: %s", ex->message);
+	} finally;
+	
+	g_free (key);
+	
 	istream = g_mime_stream_mem_new ();
 	ostream = g_mime_stream_mem_new ();
 	
@@ -332,14 +402,34 @@ int main (int argc, char **argv)
 	what = "GMimeGpgContext::encrypt";
 	testsuite_check (what);
 	try {
-		test_encrypt (ctx, istream, ostream);
+		test_encrypt (ctx, FALSE, istream, ostream);
 		testsuite_check_passed ();
 		
 		what = "GMimeGpgContext::decrypt";
 		testsuite_check (what);
 		g_mime_stream_reset (istream);
 		g_mime_stream_reset (ostream);
-		test_decrypt (ctx, istream, ostream);
+		test_decrypt (ctx, FALSE, istream, ostream);
+		testsuite_check_passed ();
+	} catch (ex) {
+		testsuite_check_failed ("%s failed: %s", what, ex->message);
+	} finally;
+	
+	g_object_unref (ostream);
+	g_mime_stream_reset (istream);
+	ostream = g_mime_stream_mem_new ();
+	
+	what = "GMimeGpgContext::encrypt+sign";
+	testsuite_check (what);
+	try {
+		test_encrypt (ctx, TRUE, istream, ostream);
+		testsuite_check_passed ();
+		
+		what = "GMimeGpgContext::decrypt+verify";
+		testsuite_check (what);
+		g_mime_stream_reset (istream);
+		g_mime_stream_reset (ostream);
+		test_decrypt (ctx, TRUE, istream, ostream);
 		testsuite_check_passed ();
 	} catch (ex) {
 		testsuite_check_failed ("%s failed: %s", what, ex->message);
